==> seedot-1.2.tar.gz: seedot-1.2/setup.py <==
import codecs
import os
from setuptools import setup, find_packages

HERE = os.path.abspath(os.path.dirname(__file__))
def read(*parts):
    """
    Build an absolute path from *parts* and and return the contents of the
    resulting file.  Assume UTF-8 encoding.
    """
    with codecs.open(os.path.join(HERE, *parts), "rb", "utf-8") as f:
        return f.read()

setup(
  name = 'seedot',
  #packages = ['GROGU'], # this must be the same as the name above
  packages = find_packages(exclude=['tests*']), # a better way to do it than the line above -- this way no typo/transpo errors
  include_package_data=True,
  version = '1.2',
  description = 'This package have 4 dictornaries for doing domain-specific sentiment analysis, the domain are: Food, Finance, Electornic, Hotel. This package work as an extension of the VADER package.',
  author = ['Seedot'],
  author_email = 'seedotvsvader@gmail.com',
  license = 'MIT License: http://opensource.org/licenses/MIT',
  #url = 'https://github.com/Lucaa00/Vader_new', # use the URL to the github repo
  install_requires = ['requests'],
  keywords = ['seedot','vader', 'sentiment', 'analysis', 'opinion', 'mining', 'nlp', 'text', 'data',
              'text analysis', 'opinion analysis', 'sentiment analysis', 'text mining', 'twitter sentiment',
              'opinion mining', 'social media', 'twitter', 'social', 'media'], # arbitrary keywords
  classifiers = ['Development Status :: 4 - Beta', 'Intended Audience :: Science/Research',
                 'License :: OSI Approved :: MIT License', 'Natural Language :: English',
                 'Programming Language :: Python :: 3.5', 'Topic :: Scientific/Engineering :: Artificial Intelligence',
                 'Topic :: Scientific/Engineering :: Information Analysis', 'Topic :: Text Processing :: Linguistic',
                 'Topic :: Text Processing :: General'],
)

==> seedot-2.1.tar.gz: seedot-2.1/setup.py <==
import codecs
import os
from setuptools import setup, find_packages

HERE = os.path.abspath(os.path.dirname(__file__))
def read(*parts):
    """
    Build an absolute path from *parts* and and return the contents of the
    resulting file.  Assume UTF-8 encoding.
    """
    with codecs.open(os.path.join(HERE, *parts), "rb", "utf-8") as f:
        return f.read()

setup(
  name = 'seedot',
  #packages = ['GROGU'], # this must be the same as the name above
  packages = find_packages(exclude=['tests*']), # a better way to do it than the line above -- this way no typo/transpo errors
  include_package_data=True,
  version = '2.1',
  author = ['Seedot'],
  author_email = 'seedotvsvader@gmail.com',
  description = 'SEEDOT: Tool for Enhancing Sentiment Lexicon with Machine Learning',
  long_description = read("README.md"),
  long_description_content_type = "text/markdown",
  license = 'MIT License: http://opensource.org/licenses/MIT',
  #url = 'https://github.com/Lucaa00/Vader_new', # use the URL to the github repo
  install_requires = ['requests'],
  keywords = ['seedot','vader', 'sentiment', 'analysis', 'opinion', 'mining', 'nlp', 'text', 'data',
              'text analysis', 'opinion analysis', 'sentiment analysis', 'text mining', 'twitter sentiment',
              'opinion mining', 'social media', 'twitter', 'social', 'media'], # arbitrary keywords
  classifiers = ['Development Status :: 4 - Beta', 'Intended Audience :: Science/Research',
                 'License :: OSI Approved :: MIT License', 'Natural Language :: English',
                 'Programming Language :: Python :: 3.5', 'Topic :: Scientific/Engineering :: Artificial Intelligence',
                 'Topic :: Scientific/Engineering :: Information Analysis', 'Topic :: Text Processing :: Linguistic',
                 'Topic :: Text Processing :: General'],
)
